//+------------------------------------------------------------------+
//|                                                    OrderInfo.mqh |
//|                      Copyright  2009, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
//+------------------------------------------------------------------+
//| Class COrderInfo.                                                |
//| Appointment: Class for access to order info.                     |
//+------------------------------------------------------------------+
class COrderInfo
  {
public:
   //--- fast access methods to the integer order propertyes
   datetime          TimeSetup();
   ENUM_ORDER_TYPE   OrderType();
   string            OrderTypeString();
   ENUM_ORDER_STATE  State();
   string            StateString();
   datetime          TimeExpiration();
   datetime          TimeDone();
   ENUM_ORDER_TYPE_FILLING TypeFilling();
   string                  TypeFillingString();
   ENUM_ORDER_TYPE_TIME    TypeTime();
   string                  TypeTimeString();
   long              Expert();
   //--- fast access methods to the double order propertyes
   double            VolumeInit();
   double            VolumeCurr();
   double            PriceOpen();
   double            StopLoss();
   double            TakeProfit();
   double            PriceCurr();
   double            PriceStopLimit();
   //--- fast access methods to the string order propertyes
   string            Symbol();
   string            Comment();
   //--- access methods to the API MQL5 functions
   long              InfoInteger(ENUM_ORDER_PROPERTY_INTEGER prop_id);
   double            InfoDouble(ENUM_ORDER_PROPERTY_DOUBLE prop_id);
   string            InfoString(ENUM_ORDER_PROPERTY_STRING prop_id);
  };
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TIME_SETUP".                       |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TIME_SETUP".                   |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
datetime COrderInfo::TimeSetup()
  {
   return((datetime)OrderGetInteger(ORDER_TIME_SETUP));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TYPE".                             |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TYPE".                         |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
ENUM_ORDER_TYPE COrderInfo::OrderType()
  {
   return((ENUM_ORDER_TYPE)OrderGetInteger(ORDER_TYPE));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TYPE" as string.                   |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TYPE" as string.               |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string COrderInfo::OrderTypeString()
  {
   string str;
//---
   switch(OrderType())
     {
      case ORDER_TYPE_BUY:
         str="Market order to buy";
         break;
      case ORDER_TYPE_SELL:
         str="Market order to sell";
         break;
      case ORDER_TYPE_BUY_LIMIT:
         str="Pending order Buy Limit";
         break;
      case ORDER_TYPE_SELL_LIMIT:
         str="Pending order Sell Limit";
         break;
      case ORDER_TYPE_BUY_STOP:
         str="Pending order Buy Stop";
         break;
      case ORDER_TYPE_SELL_STOP:
         str="Pending order Sell Stop";
         break;
      case ORDER_TYPE_BUY_STOP_LIMIT:
         str="Upon reaching the price order is placed pending order Buy Limit price StopLimit";
         break;
      case ORDER_TYPE_SELL_STOP_LIMIT:
         str="Upon reaching the price order is placed pending order Sell Limit price StopLimit";
         break;
      default:
         str="Unknown type";
     }
//---
   return(str);
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_STATE".                            |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_STATE".                        |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
ENUM_ORDER_STATE COrderInfo::State()
  {
   return((ENUM_ORDER_STATE)OrderGetInteger(ORDER_STATE));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_STATE" as string.                  |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_STATE" as string.              |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string COrderInfo::StateString()
  {
   string str;
//---
   switch(State())
     {
      case ORDER_STATE_STARTED:
         str="The order is checked for correctness, but not yet adopted broker";
         break;
      case ORDER_STATE_PLACED:
         str="The order adopted";
         break;
      case ORDER_STATE_CANCELED:
         str="Order canselled by the client";
         break;
      case ORDER_STATE_PARTIAL:
         str="Order has been partially implemented";
         break;
      case ORDER_STATE_FILLED:
         str="Order is executed completely";
         break;
      case ORDER_STATE_REJECTED:
         str="The order denied";
         break;
      case ORDER_STATE_EXPIRED:
         str="Order withdrawn after the expiry of its validity";
         break;
      default:
         str="Unknown state";
     }
//---
   return(str);
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TIME_EXPIRATION".                  |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TIME_EXPIRATION".              |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
datetime COrderInfo::TimeExpiration()
  {
   return((datetime)OrderGetInteger(ORDER_TIME_EXPIRATION));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TIME_DONE".                        |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TIME_DONE".                    |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
datetime COrderInfo::TimeDone()
  {
   return((datetime)OrderGetInteger(ORDER_TIME_DONE));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TYPE_FILLING".                     |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TYPE_FILLING".                 |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
ENUM_ORDER_TYPE_FILLING COrderInfo::TypeFilling()
  {
   return((ENUM_ORDER_TYPE_FILLING)OrderGetInteger(ORDER_TYPE_FILLING));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TYPE_FILLING" as string.           |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TYPE_FILLING" as string.       |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string COrderInfo::TypeFillingString()
  {
   string str;
//---
   switch(TypeFilling())
     {
      case ORDER_FILLING_AON:
         str="Specified volume only";
         break;
      case ORDER_FILLING_CANCEL:
         str="Most accessible market volume";
         break;
      case ORDER_FILLING_RETURN:
         str="Most accessible market volume with order the remainder";
         break;
      default:
         str="Unknown filling type";
     }
//---
   return(str);
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TYPE_TIME".                        |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TYPE_TIME".                    |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
ENUM_ORDER_TYPE_TIME COrderInfo::TypeTime()
  {
   return((ENUM_ORDER_TYPE_TIME)OrderGetInteger(ORDER_TYPE_TIME));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TYPE_TIME" as string.              |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TYPE_TIME" as string.          |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string COrderInfo::TypeTimeString()
  {
   string str;
//---
   switch(TypeTime())
     {
      case ORDER_TIME_GTC:
         str="The order will be placed in the queue until withdrawn";
         break;
      case ORDER_TIME_DAY:
         str="Order shall be effective only during the current trading day";
         break;
      case ORDER_TIME_SPECIFIED:
         str="Order will be valid until the expiry";
         break;
      default:
         str="Unknown time type";
     }
//---
   return(str);
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_EXPERT".                           |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_EXPERT".                       |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
long COrderInfo::Expert()
  {
   return(OrderGetInteger(ORDER_EXPERT));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_VOLUME_INITIAL".                   |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_VOLUME_INITIAL".               |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double COrderInfo::VolumeInit()
  {
   return(OrderGetDouble(ORDER_VOLUME_INITIAL));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_VOLUME_CURRENT".                   |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_VOLUME_CURRENT".               |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double COrderInfo::VolumeCurr()
  {
   return(OrderGetDouble(ORDER_VOLUME_CURRENT));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_PRICE_OPEN".                       |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_PRICE_OPEN".                   |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double COrderInfo::PriceOpen()
  {
   return(OrderGetDouble(ORDER_PRICE_OPEN));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_SL".                               |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_SL".                           |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double COrderInfo::StopLoss()
  {
   return(OrderGetDouble(ORDER_SL));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_TP".                               |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_TP".                           |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double COrderInfo::TakeProfit()
  {
   return(OrderGetDouble(ORDER_TP));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_PRICE_CURRENT".                    |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_PRICE_CURRENT".                |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double COrderInfo::PriceCurr()
  {
   return(OrderGetDouble(ORDER_PRICE_CURRENT));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_PRICE_STOPLIMIT".                  |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_PRICE_STOPLIMIT".              |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double COrderInfo::PriceStopLimit()
  {
   return(OrderGetDouble(ORDER_PRICE_STOPLIMIT));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_SYMBOL".                           |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_SYMBOL".                       |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string COrderInfo::Symbol()
  {
   return(OrderGetString(ORDER_SYMBOL));
  }
//+------------------------------------------------------------------+
//| Get the property value "ORDER_COMMENT".                          |
//| INPUT:  no.                                                      |
//| OUTPUT: the property value "ORDER_COMMENT".                      |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string COrderInfo::Comment()
  {
   return(OrderGetString(ORDER_COMMENT));
  }
//+------------------------------------------------------------------+
//| Access functions OrderGetInteger(...).                           |
//| INPUT:  prop_id  -identifier integer properties.                 |
//| OUTPUT: the integer property value.                              |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
long COrderInfo::InfoInteger(ENUM_ORDER_PROPERTY_INTEGER prop_id)
  {
   return(OrderGetInteger(prop_id));
  }
//+------------------------------------------------------------------+
//| Access functions OrderGetDouble(...).                            |
//| INPUT:  prop_id  -identifier double properties.                  |
//| OUTPUT: the double property value.                               |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
double COrderInfo::InfoDouble(ENUM_ORDER_PROPERTY_DOUBLE prop_id)
  {
   return(OrderGetDouble(prop_id));
  }
//+------------------------------------------------------------------+
//| Access functions OrderGetString(...).                            |
//| INPUT:  prop_id  -identifier string properties.                  |
//| OUTPUT: the string property value.                               |
//| REMARK: no.                                                      |
//+------------------------------------------------------------------+
string COrderInfo::InfoString(ENUM_ORDER_PROPERTY_STRING prop_id)
  {
   return(OrderGetString(prop_id));
  }
//+------------------------------------------------------------------+
